"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _graphql = require("graphql");

var _commonTags = require("common-tags");

var _gatsbyCloudinary = require("@dylanvann/gatsby-cloudinary");

var _default = ({
  pathPrefix,
  getNodeAndSavePathDependency,
  reporter,
  cloudinaryConfig
}) => {
  return {
    type: new _graphql.GraphQLObjectType({
      name: 'ImageCloudinaryFluid',
      fields: {
        width: {
          type: _graphql.GraphQLFloat,
          description: 'The original width of the media.'
        },
        height: {
          type: _graphql.GraphQLFloat,
          description: 'The original height of the media.'
        },
        // ----------------------------------------
        // img
        // ----------------------------------------
        imgSrc: {
          type: _graphql.GraphQLString,
          description: _commonTags.oneLine`
                        src for the image.
                    `
        },
        imgSrcSet: {
          type: _graphql.GraphQLString,
          description: _commonTags.oneLine`
                        srcSet for the image.
                    `
        },
        imgWebPSrc: {
          type: _graphql.GraphQLString,
          description: _commonTags.oneLine`
                        src for the image (WebP).
                    `
        },
        imgWebPSrcSet: {
          type: _graphql.GraphQLString,
          description: _commonTags.oneLine`
                        srcSet for the image (WebP).
                    `
        },
        imgBase64: {
          type: _graphql.GraphQLString,
          description: _commonTags.oneLine`
                        A base64 version of the image.
                    `
        },
        // ----------------------------------------
        // video
        //
        // no srcSet or base64
        // as those do not make sense for videos
        // ----------------------------------------
        videoSrc: {
          type: _graphql.GraphQLString,
          description: _commonTags.oneLine`
                       src for the video.
                    `
        },
        // ----------------------------------------
        // videoPoster
        // ----------------------------------------
        videoPosterSrc: {
          type: _graphql.GraphQLString,
          description: _commonTags.oneLine`
                       src for the poster.
                    `
        },
        videoPosterSrcSet: {
          type: _graphql.GraphQLString,
          description: _commonTags.oneLine`
                       srcSet for the poster.
                    `
        },
        videoPosterBase64: {
          type: _graphql.GraphQLString,
          description: _commonTags.oneLine`
                       A base64 version of the poster.
                    `
        },
        sizes: {
          type: _graphql.GraphQLString
        }
      }
    }),
    args: {
      maxWidth: {
        type: _graphql.GraphQLInt,
        description: 'The max width the media will be displayed at.',
        defaultValue: 800
      },
      maxHeight: {
        type: _graphql.GraphQLInt,
        description: _commonTags.oneLine`
                    The max height the media will be displayed at.
                    You probably want to use maxWidth instead of this.
                `
      },
      toImgFormat: {
        type: _graphql.GraphQLString,
        description: 'Format to convert img to.'
      },
      toVideoFormat: {
        type: _graphql.GraphQLString,
        description: 'Format to convert video to.'
      },
      toVideoPosterFormat: {
        type: _graphql.GraphQLString,
        description: 'Format to convert videoPoster to.'
      }
    },
    resolve: async (image, fieldArgs, context) => {
      try {
        const file = getNodeAndSavePathDependency(image.parent, context.path);
        const path = file.absolutePath;
        const maxWidth = fieldArgs.maxWidth;
        const props = await (0, _gatsbyCloudinary.getData)({
          path,
          maxWidth,
          config: cloudinaryConfig,
          toImgFormat: fieldArgs.toImgFormat,
          toVideoFormat: fieldArgs.toVideoFormat,
          toVideoPosterFormat: fieldArgs.toVideoPosterFormat
        });
        return props;
      } catch (e) {
        console.error(e);
        return {};
      }
    }
  };
};

exports.default = _default;